@@ -11,22 +11,22 @@ use Term::ANSIColor qw(:constants);
 warn "Loading module - Trans_cod ...\n";
 
 my $prior=1;
-my $color=0;
+my $colour=0;
 return true;
 
 sub set_debug_level
 {
    my $tmp=shift;
    my $tmpC=shift;
-   return "Error - debug level out of range" if($tmp<0 or $tmp>9);
+   return "Error - debug level out of range" if($tmp<0 or $tmp>5);
    $prior=$tmp;
-   $color=$tmpC if($tmpC==0 or $tmpC==1);
+   $colour=$tmpC if($tmpC==0 or $tmpC==1);
    return "true";
 }
 
 sub clean_and_lc
   {
-    mess('Text "cleaning" ...',5);
+    mess('"Cistenie" textu ...',5);
     my $in=shift(@_);
     $_=$in;
     s/[\n]+//g;
@@ -45,7 +45,7 @@ sub clean_and_lc
 
 sub cod2uni
   {
-    mess("Conversion to internal coding ...",5);
+    mess("Prekodovanie do interneho kodovania ...",5);
     my %cod=('a'=>'!a!',''=>'!A!',''=>'!e!','b'=>'!b!','c'=>'!c!',''=>'!C!',
 	     'd'=>'!d!',''=>'!D!','e'=>'!e!',''=>'!E!','f'=>'!f!','g'=>'!g!',
 	     'h'=>'!h!','i'=>'!i!',''=>'!I!','j'=>'!j!','k'=>'!k!','l'=>'!l!',
@@ -69,7 +69,7 @@ sub cod2uni
 
 sub uni2cod
   {
-    mess("Conversion from internal coding ...",5);
+    mess("Prekodovanie z interneho kodovania ...",5);
     my %cod=('!a!'=>'a','!A!'=>'','!e!'=>'','!b!'=>'b','!c!'=>'c','!C!'=>'',
 	     '!d!'=>'d','!D!'=>'','!e!'=>'e','!E!'=>'','!f!'=>'f','!g!'=>'g',
 	     '!h!'=>'h','!i!'=>'i','!I!'=>'','!j!'=>'j','!k!'=>'k','!l!'=>'l',
@@ -98,8 +98,8 @@ sub uni2cod
 
 sub lc_1
   {
-    mess("Changing to lower case ...",5);
-    my %ul1=('A'=>'a',''=>'',''=>'','B'=>'b','C'=>'c',''=>'','D'=>'d',''=>'','E'=>'e',
+    mess("Zmena vsetkych velkych pismen na male ...",5);
+    my %ul1=('A'=>'a',''=>'','B'=>'b','C'=>'c',''=>'','D'=>'d',''=>'','E'=>'e',
 	     ''=>'','F'=>'f','G'=>'g','H'=>'h','I'=>'i',''=>'','J'=>'j','K'=>'k',
 	     'L'=>'l',''=>'',''=>'','M'=>'m','N'=>'n',''=>'','O'=>'o',''=>'',
 	     ''=>'','P'=>'p','Q'=>'q','R'=>'r',''=>'','S'=>'s',''=>'','T'=>'t',
@@ -123,13 +123,13 @@ sub mess
       {
         $nt=$pr-1; $ss="";
 	for($x=0;$x<$nt;$x++){$ss.="\t";}
-	print "$ss$msg \n" if($color==0);
+	print "$ss$msg \n" if($colour==0);
         #1-YELLOW,BOLD,2-YELLOW,3-GREEN,         5-default
-        print YELLOW,BOLD,"$msg \n",RESET if($pr==1 and $color==1);
-        print YELLOW,"$ss$msg \n",RESET if($pr==2 and $color==1);
-        print GREEN,"$ss$msg \n",RESET if($pr==3 and $color==1);
-        print BLUE,"$ss$msg \n",RESET if($pr==4 and $color==1);
-        print RESET,"$ss$msg \n" if($pr==5 and $color==1);
+        print YELLOW,BOLD,"$msg \n",RESET if($pr==1 and $colour==1);
+        print YELLOW,"$ss$msg \n",RESET if($pr==2 and $colour==1);
+        print GREEN,"$ss$msg \n",RESET if($pr==3 and $colour==1);
+        print BLUE,"$ss$msg \n",RESET if($pr==4 and $colour==1);
+        print RESET,"$ss$msg \n" if($pr==5 and $colour==1);
       }
   }
 
