@@ -13,7 +13,7 @@ warn "Loading module - Trans_morfemy ...\n";
 my $morfemat="/usr/share/g2p_sk/Exceptions/morfemy.ddat";
 my %morf;
 my $prior=1;
-my $color=0;
+my $colour=0;
 
 mess("Reading dictionary ...",1);
 read_dictionary();
@@ -23,9 +23,9 @@ sub set_debug_level
 {
    my $tmp=shift;
    my $tmpC=shift;
-   return "Error - debug level out of range" if($tmp<0 or $tmp>9);
+   return "Error - debug level out of range" if($tmp<0 or $tmp>5);
    $prior=$tmp;
-   $color=$tmpC if($tmpC==0 or $tmpC==1);
+   $colour=$tmpC if($tmpC==0 or $tmpC==1);
    return "true";
 }
 
@@ -54,7 +54,7 @@ sub member
 sub read_dictionary
 {
  open (STAT,"< $morfemat") or
-    die ("Can not open file $morfemat!!!\n");
+    die ("Nie je mozne otvorit vstupny subor $morfemat!!!\n");
  while(<STAT>)
  {
   chomp;
@@ -72,13 +72,13 @@ sub mess
       {
         $nt=$pr-1; $ss="";
 	for($x=0;$x<$nt;$x++){$ss.="\t";}
-	print "$ss$msg \n" if($color==0);
+	print "$ss$msg \n" if($colour==0);
         #1-YELLOW,BOLD,2-YELLOW,3-GREEN,         5-default
-        print YELLOW,BOLD,"$msg \n",RESET if($pr==1 and $color==1);
-        print YELLOW,"$ss$msg \n",RESET if($pr==2 and $color==1);
-        print GREEN,"$ss$msg \n",RESET if($pr==3 and $color==1);
-        print BLUE,"$ss$msg \n",RESET if($pr==4 and $color==1);
-        print RESET,"$ss$msg \n" if($pr==5 and $color==1);
+        print YELLOW,BOLD,"$msg \n",RESET if($pr==1 and $colour==1);
+        print YELLOW,"$ss$msg \n",RESET if($pr==2 and $colour==1);
+        print GREEN,"$ss$msg \n",RESET if($pr==3 and $colour==1);
+        print BLUE,"$ss$msg \n",RESET if($pr==4 and $colour==1);
+        print RESET,"$ss$msg \n" if($pr==5 and $colour==1);
       }
   }
 
